@@ -1,7 +1,7 @@
 """
 Type annotations for ds service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/literals/)
 
 Usage::
 
@@ -24,11 +24,16 @@ __all__ = (
     "CertificateTypeType",
     "ClientAuthenticationStatusType",
     "ClientAuthenticationTypeType",
+    "DescribeClientAuthenticationSettingsPaginatorName",
     "DescribeDirectoriesPaginatorName",
     "DescribeDomainControllersPaginatorName",
+    "DescribeLDAPSSettingsPaginatorName",
+    "DescribeRegionsPaginatorName",
     "DescribeSharedDirectoriesPaginatorName",
     "DescribeSnapshotsPaginatorName",
     "DescribeTrustsPaginatorName",
+    "DescribeUpdateDirectoryPaginatorName",
+    "DirectoryConfigurationStatusType",
     "DirectoryEditionType",
     "DirectorySizeType",
     "DirectoryStageType",
@@ -37,10 +42,12 @@ __all__ = (
     "IpRouteStatusMsgType",
     "LDAPSStatusType",
     "LDAPSTypeType",
+    "ListCertificatesPaginatorName",
     "ListIpRoutesPaginatorName",
     "ListLogSubscriptionsPaginatorName",
     "ListSchemaExtensionsPaginatorName",
     "ListTagsForResourcePaginatorName",
+    "OSVersionType",
     "RadiusAuthenticationProtocolType",
     "RadiusStatusType",
     "RegionTypeType",
@@ -56,8 +63,13 @@ __all__ = (
     "TrustDirectionType",
     "TrustStateType",
     "TrustTypeType",
+    "UpdateStatusType",
+    "UpdateTypeType",
+    "DirectoryServiceServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -71,12 +83,19 @@ CertificateStateType = Literal[
 ]
 CertificateTypeType = Literal["ClientCertAuth", "ClientLDAPS"]
 ClientAuthenticationStatusType = Literal["Disabled", "Enabled"]
-ClientAuthenticationTypeType = Literal["SmartCard"]
+ClientAuthenticationTypeType = Literal["SmartCard", "SmartCardOrPassword"]
+DescribeClientAuthenticationSettingsPaginatorName = Literal[
+    "describe_client_authentication_settings"
+]
 DescribeDirectoriesPaginatorName = Literal["describe_directories"]
 DescribeDomainControllersPaginatorName = Literal["describe_domain_controllers"]
+DescribeLDAPSSettingsPaginatorName = Literal["describe_ldaps_settings"]
+DescribeRegionsPaginatorName = Literal["describe_regions"]
 DescribeSharedDirectoriesPaginatorName = Literal["describe_shared_directories"]
 DescribeSnapshotsPaginatorName = Literal["describe_snapshots"]
 DescribeTrustsPaginatorName = Literal["describe_trusts"]
+DescribeUpdateDirectoryPaginatorName = Literal["describe_update_directory"]
+DirectoryConfigurationStatusType = Literal["Default", "Failed", "Requested", "Updated", "Updating"]
 DirectoryEditionType = Literal["Enterprise", "Standard"]
 DirectorySizeType = Literal["Large", "Small"]
 DirectoryStageType = Literal[
@@ -101,10 +120,12 @@ IpRouteStatusMsgType = Literal[
 ]
 LDAPSStatusType = Literal["Disabled", "EnableFailed", "Enabled", "Enabling"]
 LDAPSTypeType = Literal["Client"]
+ListCertificatesPaginatorName = Literal["list_certificates"]
 ListIpRoutesPaginatorName = Literal["list_ip_routes"]
 ListLogSubscriptionsPaginatorName = Literal["list_log_subscriptions"]
 ListSchemaExtensionsPaginatorName = Literal["list_schema_extensions"]
 ListTagsForResourcePaginatorName = Literal["list_tags_for_resource"]
+OSVersionType = Literal["SERVER_2012", "SERVER_2019"]
 RadiusAuthenticationProtocolType = Literal["CHAP", "MS-CHAPv1", "MS-CHAPv2", "PAP"]
 RadiusStatusType = Literal["Completed", "Creating", "Failed"]
 RegionTypeType = Literal["Additional", "Primary"]
@@ -152,6 +173,9 @@ TrustStateType = Literal[
     "Verifying",
 ]
 TrustTypeType = Literal["External", "Forest"]
+UpdateStatusType = Literal["UpdateFailed", "Updated", "Updating"]
+UpdateTypeType = Literal["OS"]
+DirectoryServiceServiceName = Literal["ds"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -182,12 +206,15 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -220,7 +247,10 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -256,6 +286,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
@@ -269,6 +300,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -296,15 +328,18 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -320,12 +355,14 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -347,6 +384,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
@@ -369,8 +407,10 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -381,11 +421,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -431,6 +473,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
@@ -453,14 +496,55 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
+    "describe_client_authentication_settings",
     "describe_directories",
     "describe_domain_controllers",
+    "describe_ldaps_settings",
+    "describe_regions",
     "describe_shared_directories",
     "describe_snapshots",
     "describe_trusts",
+    "describe_update_directory",
+    "list_certificates",
     "list_ip_routes",
     "list_log_subscriptions",
     "list_schema_extensions",
     "list_tags_for_resource",
 ]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ap-southeast-3",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
