@@ -1,7 +1,7 @@
 """
 Type annotations for ds service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/)
 
 Usage::
 
@@ -10,11 +10,16 @@ Usage::
 
     from mypy_boto3_ds.client import DirectoryServiceClient
     from mypy_boto3_ds.paginator import (
+        DescribeClientAuthenticationSettingsPaginator,
         DescribeDirectoriesPaginator,
         DescribeDomainControllersPaginator,
+        DescribeLDAPSSettingsPaginator,
+        DescribeRegionsPaginator,
         DescribeSharedDirectoriesPaginator,
         DescribeSnapshotsPaginator,
         DescribeTrustsPaginator,
+        DescribeUpdateDirectoryPaginator,
+        ListCertificatesPaginator,
         ListIpRoutesPaginator,
         ListLogSubscriptionsPaginator,
         ListSchemaExtensionsPaginator,
@@ -24,28 +29,39 @@ Usage::
     session = Session()
     client: DirectoryServiceClient = session.client("ds")
 
+    describe_client_authentication_settings_paginator: DescribeClientAuthenticationSettingsPaginator = client.get_paginator("describe_client_authentication_settings")
     describe_directories_paginator: DescribeDirectoriesPaginator = client.get_paginator("describe_directories")
     describe_domain_controllers_paginator: DescribeDomainControllersPaginator = client.get_paginator("describe_domain_controllers")
+    describe_ldaps_settings_paginator: DescribeLDAPSSettingsPaginator = client.get_paginator("describe_ldaps_settings")
+    describe_regions_paginator: DescribeRegionsPaginator = client.get_paginator("describe_regions")
     describe_shared_directories_paginator: DescribeSharedDirectoriesPaginator = client.get_paginator("describe_shared_directories")
     describe_snapshots_paginator: DescribeSnapshotsPaginator = client.get_paginator("describe_snapshots")
     describe_trusts_paginator: DescribeTrustsPaginator = client.get_paginator("describe_trusts")
+    describe_update_directory_paginator: DescribeUpdateDirectoryPaginator = client.get_paginator("describe_update_directory")
+    list_certificates_paginator: ListCertificatesPaginator = client.get_paginator("list_certificates")
     list_ip_routes_paginator: ListIpRoutesPaginator = client.get_paginator("list_ip_routes")
     list_log_subscriptions_paginator: ListLogSubscriptionsPaginator = client.get_paginator("list_log_subscriptions")
     list_schema_extensions_paginator: ListSchemaExtensionsPaginator = client.get_paginator("list_schema_extensions")
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
     ```
 """
+import sys
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
+from .literals import ClientAuthenticationTypeType
 from .type_defs import (
+    DescribeClientAuthenticationSettingsResultTypeDef,
     DescribeDirectoriesResultTypeDef,
     DescribeDomainControllersResultTypeDef,
+    DescribeLDAPSSettingsResultTypeDef,
+    DescribeRegionsResultTypeDef,
     DescribeSharedDirectoriesResultTypeDef,
     DescribeSnapshotsResultTypeDef,
     DescribeTrustsResultTypeDef,
+    DescribeUpdateDirectoryResultTypeDef,
+    ListCertificatesResultTypeDef,
     ListIpRoutesResultTypeDef,
     ListLogSubscriptionsResultTypeDef,
     ListSchemaExtensionsResultTypeDef,
@@ -53,12 +69,23 @@ from .type_defs import (
     PaginatorConfigTypeDef,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 __all__ = (
+    "DescribeClientAuthenticationSettingsPaginator",
     "DescribeDirectoriesPaginator",
     "DescribeDomainControllersPaginator",
+    "DescribeLDAPSSettingsPaginator",
+    "DescribeRegionsPaginator",
     "DescribeSharedDirectoriesPaginator",
     "DescribeSnapshotsPaginator",
     "DescribeTrustsPaginator",
+    "DescribeUpdateDirectoryPaginator",
+    "ListCertificatesPaginator",
     "ListIpRoutesPaginator",
     "ListLogSubscriptionsPaginator",
     "ListSchemaExtensionsPaginator",
@@ -76,10 +103,29 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class DescribeDirectoriesPaginator(Boto3Paginator):
+class DescribeClientAuthenticationSettingsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeClientAuthenticationSettings)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeclientauthenticationsettingspaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        DirectoryId: str,
+        Type: ClientAuthenticationTypeType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeClientAuthenticationSettingsResultTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeClientAuthenticationSettings.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeclientauthenticationsettingspaginator)
+        """
+
+
+class DescribeDirectoriesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describedirectoriespaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describedirectoriespaginator)
     """
 
     def paginate(
@@ -87,14 +133,14 @@ class DescribeDirectoriesPaginator(Boto3Paginator):
     ) -> _PageIterator[DescribeDirectoriesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describedirectoriespaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describedirectoriespaginator)
         """
 
 
-class DescribeDomainControllersPaginator(Boto3Paginator):
+class DescribeDomainControllersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describedomaincontrollerspaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describedomaincontrollerspaginator)
     """
 
     def paginate(
@@ -106,14 +152,52 @@ class DescribeDomainControllersPaginator(Boto3Paginator):
     ) -> _PageIterator[DescribeDomainControllersResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describedomaincontrollerspaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describedomaincontrollerspaginator)
         """
 
 
-class DescribeSharedDirectoriesPaginator(Boto3Paginator):
+class DescribeLDAPSSettingsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeLDAPSSettings)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeldapssettingspaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        DirectoryId: str,
+        Type: Literal["Client"] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeLDAPSSettingsResultTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeLDAPSSettings.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeldapssettingspaginator)
+        """
+
+
+class DescribeRegionsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeRegions)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeregionspaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        DirectoryId: str,
+        RegionName: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeRegionsResultTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeRegions.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeregionspaginator)
+        """
+
+
+class DescribeSharedDirectoriesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describeshareddirectoriespaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeshareddirectoriespaginator)
     """
 
     def paginate(
@@ -125,14 +209,14 @@ class DescribeSharedDirectoriesPaginator(Boto3Paginator):
     ) -> _PageIterator[DescribeSharedDirectoriesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describeshareddirectoriespaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeshareddirectoriespaginator)
         """
 
 
-class DescribeSnapshotsPaginator(Boto3Paginator):
+class DescribeSnapshotsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describesnapshotspaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describesnapshotspaginator)
     """
 
     def paginate(
@@ -144,14 +228,14 @@ class DescribeSnapshotsPaginator(Boto3Paginator):
     ) -> _PageIterator[DescribeSnapshotsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describesnapshotspaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describesnapshotspaginator)
         """
 
 
-class DescribeTrustsPaginator(Boto3Paginator):
+class DescribeTrustsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describetrustspaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describetrustspaginator)
     """
 
     def paginate(
@@ -163,14 +247,49 @@ class DescribeTrustsPaginator(Boto3Paginator):
     ) -> _PageIterator[DescribeTrustsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describetrustspaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describetrustspaginator)
         """
 
 
-class ListIpRoutesPaginator(Boto3Paginator):
+class DescribeUpdateDirectoryPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeUpdateDirectory)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeupdatedirectorypaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        DirectoryId: str,
+        UpdateType: Literal["OS"],
+        RegionName: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeUpdateDirectoryResultTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.DescribeUpdateDirectory.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#describeupdatedirectorypaginator)
+        """
+
+
+class ListCertificatesPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListCertificates)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listcertificatespaginator)
+    """
+
+    def paginate(
+        self, *, DirectoryId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListCertificatesResultTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListCertificates.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listcertificatespaginator)
+        """
+
+
+class ListIpRoutesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listiproutespaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listiproutespaginator)
     """
 
     def paginate(
@@ -178,14 +297,14 @@ class ListIpRoutesPaginator(Boto3Paginator):
     ) -> _PageIterator[ListIpRoutesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listiproutespaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listiproutespaginator)
         """
 
 
-class ListLogSubscriptionsPaginator(Boto3Paginator):
+class ListLogSubscriptionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listlogsubscriptionspaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listlogsubscriptionspaginator)
     """
 
     def paginate(
@@ -193,14 +312,14 @@ class ListLogSubscriptionsPaginator(Boto3Paginator):
     ) -> _PageIterator[ListLogSubscriptionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listlogsubscriptionspaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listlogsubscriptionspaginator)
         """
 
 
-class ListSchemaExtensionsPaginator(Boto3Paginator):
+class ListSchemaExtensionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listschemaextensionspaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listschemaextensionspaginator)
     """
 
     def paginate(
@@ -208,14 +327,14 @@ class ListSchemaExtensionsPaginator(Boto3Paginator):
     ) -> _PageIterator[ListSchemaExtensionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listschemaextensionspaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listschemaextensionspaginator)
         """
 
 
-class ListTagsForResourcePaginator(Boto3Paginator):
+class ListTagsForResourcePaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listtagsforresourcepaginator)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listtagsforresourcepaginator)
     """
 
     def paginate(
@@ -223,5 +342,5 @@ class ListTagsForResourcePaginator(Boto3Paginator):
     ) -> _PageIterator[ListTagsForResourceResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listtagsforresourcepaginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators/#listtagsforresourcepaginator)
         """
